@@ -13,6 +13,11 @@ LOG
 #ifndef INCLUDE_CPPEXTERN_H_
 #define INCLUDE_CPPEXTERN_H_
 
+#ifdef NT
+#pragma warning( disable : 4244 )
+#pragma warning( disable : 4305 )
+#pragma warning( disable : 4091 )
+#endif
 
 #include "m_pd.h"
 #include "Base/GemExportDef.h"
@@ -99,11 +104,16 @@ class GEM_EXTERN CPPExtern
         // This is a holder - don't touch it
         static t_object     *m_holder;
 
+	//////////
+	// my name
+	t_symbol             *m_objectname;
+        void                  setCPPObjectName(char* name);
+
     protected:
     	
     	//////////
     	// Creation callback
-    	static void 	real_obj_setupCallback(t_class *) {}	
+    	static void 	real_obj_setupCallback(t_class *) {}
 
     private:
 
@@ -174,12 +184,50 @@ static void obj_setupCallback(t_class *classPtr);
     REAL_NEW_WITH_ARG_ARG_ARG_ARG(NEW_CLASS, _setup, _class, TYPE, PD_TYPE, TTWO, PD_TWO, TTHREE, PD_THREE, TFOUR, PD_FOUR)
 
 
-///////////////////////////////////////////////////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
 // These should never be called or used directly!!!
 //
 //
 ///////////////////////////////////////////////////////////////////////////////
+
 ///////////////////////////////////////////////////////////////////////////////
+// auto registering a class
+// this creates a dummy class, whose constructor calls the setup-function 
+// (registering the class with pd)
+// a static copy of this class is created at runtime, to actually do the setup-call
+///////////////////////////////////////////////////////////////////////////////
+#ifdef NO_AUTO_REGISTER_CLASS
+// if NO_AUTO_REGISTER_CLASS is defined, we will not register the class
+# define AUTO_REGISTER_CLASS(NEW_CLASS, SETUP_FUNCTION)
+#else
+// for debugging we can show the which classes are auto-registering
+# if 0
+#  define POST_AUTOREGISTER(NEW_CLASS) post("auto-registering: "#NEW_CLASS);
+# else
+#  define POST_AUTOREGISTER(NEW_CLASS)
+# endif
+# define AUTO_REGISTER_CLASS(NEW_CLASS, SETUP_FUNCTION)			\
+  class NEW_CLASS ## _cppclass {					\
+  public:								\
+  NEW_CLASS ## _cppclass() {POST_AUTOREGISTER(NEW_CLASS); NEW_CLASS ## SETUP_FUNCTION(); } \
+};									\
+  static NEW_CLASS ## _cppclass NEW_CLASS ## _instance;
+#endif
+
+///////////////////////////////////////////////////////////////////////////////
+// setting the help-symbol
+///////////////////////////////////////////////////////////////////////////////
+#ifndef HELPSYMBOL_BASE
+# define HELPSYMBOL_BASE ""
+#endif
+
+#ifdef HELPSYMBOL
+# define SET_HELPSYMBOL(NEW_CLASS, EXTERN_NAME)				\
+  class_sethelpsymbol(NEW_CLASS ## EXTERN_NAME, gensym(HELPSYMBOL_BASE HELPSYMBOL));
+#else 
+# define SET_HELPSYMBOL(NEW_CLASS, EXTERN_NAME)			\
+  class_sethelpsymbol(NEW_CLASS ## EXTERN_NAME, gensym(HELPSYMBOL_BASE#NEW_CLASS));
+#endif /* HELPSYMBOL */
 
 ///////////////////////////////////////////////////////////////////////////////
 // no args
@@ -192,6 +240,7 @@ void * EXTERN_NAME ## NEW_CLASS ()                              \
     CPPExtern::m_holder = &obj->pd_obj;                         \
     obj->data = new NEW_CLASS;                                  \
     CPPExtern::m_holder = NULL;                                 \
+    obj->data->setCPPObjectName(#NEW_CLASS);                \
     return(obj);                                                \
 }   	    	    	    	    	    	    	    	\
 extern "C" {	    	    	    	    	    	    	\
@@ -203,9 +252,12 @@ void NEW_CLASS ## SETUP_FUNCTION()    	    	    	    	\
     	    	(t_method)&NEW_CLASS::obj_freeCallback,         \
     	     	sizeof(Obj_header), 0,                          \
     	     	A_NULL);                                        \
-    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## EXTERN_NAME); \
-}   	    	    	    	    	    	    	    	\
-}
+    SET_HELPSYMBOL(NEW_CLASS, EXTERN_NAME);				\
+    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## EXTERN_NAME);	\
+ }									\
+}									\
+  AUTO_REGISTER_CLASS(NEW_CLASS, SETUP_FUNCTION);
+
 
 ///////////////////////////////////////////////////////////////////////////////
 // one arg
@@ -218,6 +270,7 @@ void * EXTERN_NAME ## NEW_CLASS (VAR_TYPE arg)                  \
     CPPExtern::m_holder = &obj->pd_obj;                         \
     obj->data = new NEW_CLASS(arg);                             \
     CPPExtern::m_holder = NULL;                                 \
+    obj->data->setCPPObjectName(#NEW_CLASS);                \
     return(obj);                                                \
 }   	    	    	    	    	    	    	    	\
 extern "C" {	    	    	    	    	    	    	\
@@ -230,9 +283,11 @@ void NEW_CLASS ## SETUP_FUNCTION()    	    	    	    	\
     	     	sizeof(Obj_header), 0,                          \
     	     	PD_TYPE,                                        \
     	     	A_NULL);      	    	    	    	    	\
-    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## EXTERN_NAME); \
-}   	    	    	    	    	    	    	    	\
-}
+    SET_HELPSYMBOL(NEW_CLASS, EXTERN_NAME);				\
+    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## EXTERN_NAME);	\
+ }									\
+}									\
+  AUTO_REGISTER_CLASS(NEW_CLASS, SETUP_FUNCTION);
 
 ///////////////////////////////////////////////////////////////////////////////
 // gimme arg
@@ -245,6 +300,7 @@ void * EXTERN_NAME ## NEW_CLASS (t_symbol *, int argc, t_atom *argv) \
     CPPExtern::m_holder = &obj->pd_obj;                         \
     obj->data = new NEW_CLASS(argc, argv);                      \
     CPPExtern::m_holder = NULL;                                 \
+    obj->data->setCPPObjectName(#NEW_CLASS);                 \
     return(obj);                                                \
 }   	    	    	    	    	    	    	    	\
 extern "C" {	    	    	    	    	    	    	\
@@ -257,9 +313,11 @@ void NEW_CLASS ## SETUP_FUNCTION()    	    	    	    	\
     	     	sizeof(Obj_header), 0,                          \
     	     	A_GIMME,                                        \
     	     	A_NULL);      	    	    	    	    	\
-    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## EXTERN_NAME); \
-}   	    	    	    	    	    	    	    	\
-}
+    SET_HELPSYMBOL(NEW_CLASS, EXTERN_NAME);				\
+    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## EXTERN_NAME);	\
+ }									\
+}									\
+  AUTO_REGISTER_CLASS(NEW_CLASS, SETUP_FUNCTION);
 
 ///////////////////////////////////////////////////////////////////////////////
 // two args
@@ -272,6 +330,7 @@ void * EXTERN_NAME ## NEW_CLASS (ONE_VAR_TYPE arg, TWO_VAR_TYPE argtwo) \
     CPPExtern::m_holder = &obj->pd_obj;                         \
     obj->data = new NEW_CLASS(arg, argtwo);                     \
     CPPExtern::m_holder = NULL;                                 \
+    obj->data->setCPPObjectName(#NEW_CLASS);                \
     return(obj);                                                \
 }   	    	    	    	    	    	    	    	\
 extern "C" {	    	    	    	    	    	    	\
@@ -284,9 +343,11 @@ void NEW_CLASS ## SETUP_FUNCTION()    	    	    	    	\
     	     	sizeof(Obj_header), 0,                          \
     	     	ONE_PD_TYPE, TWO_PD_TYPE,                       \
     	     	A_NULL);      	    	    	    	    	\
-    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## EXTERN_NAME); \
-}   	    	    	    	    	    	    	    	\
-}
+    SET_HELPSYMBOL(NEW_CLASS, EXTERN_NAME);				\
+    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## EXTERN_NAME);	\
+ }									\
+}									\
+  AUTO_REGISTER_CLASS(NEW_CLASS, SETUP_FUNCTION);
 
 ///////////////////////////////////////////////////////////////////////////////
 // three args
@@ -299,6 +360,7 @@ void * EXTERN_NAME ## NEW_CLASS (ONE_VAR_TYPE arg, TWO_VAR_TYPE argtwo, THREE_VA
     CPPExtern::m_holder = &obj->pd_obj;                         \
     obj->data = new NEW_CLASS(arg, argtwo, argthree);           \
     CPPExtern::m_holder = NULL;                                 \
+    obj->data->setCPPObjectName(#NEW_CLASS);                \
     return(obj);                                                \
 }   	    	    	    	    	    	    	    	\
 extern "C" {	    	    	    	    	    	    	\
@@ -311,9 +373,11 @@ void NEW_CLASS ## SETUP_FUNCTION()    	    	    	    	\
     	     	sizeof(Obj_header), 0,                          \
     	     	ONE_PD_TYPE, TWO_PD_TYPE, THREE_PD_TYPE,        \
     	     	A_NULL);      	    	    	    	    	\
-    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## EXTERN_NAME); \
-}   	    	    	    	    	    	    	    	\
-}
+    SET_HELPSYMBOL(NEW_CLASS, EXTERN_NAME);				\
+    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## EXTERN_NAME);	\
+ }									\
+}									\
+  AUTO_REGISTER_CLASS(NEW_CLASS, SETUP_FUNCTION);
 
 ///////////////////////////////////////////////////////////////////////////////
 // four args
@@ -326,6 +390,7 @@ void * EXTERN_NAME ## NEW_CLASS (ONE_VAR_TYPE arg, TWO_VAR_TYPE argtwo, THREE_VA
     CPPExtern::m_holder = &obj->pd_obj;                         \
     obj->data = new NEW_CLASS(arg, argtwo, argthree, argfour);  \
     CPPExtern::m_holder = NULL;                                 \
+    obj->data->setCPPObjectName(#NEW_CLASS);                \
     return(obj);                                                \
 }   	    	    	    	    	    	    	    	\
 extern "C" {	    	    	    	    	    	    	\
@@ -336,11 +401,12 @@ void NEW_CLASS ## SETUP_FUNCTION()    	    	    	    	\
     	    	(t_newmethod)EXTERN_NAME ## NEW_CLASS,	    	\
     	    	(t_method)&NEW_CLASS::obj_freeCallback,         \
     	     	sizeof(Obj_header), 0,                          \
-    	     	ONE_PD_TYPE, TWO_PD_TYPE, THREE_PD_TYPE, FOUR_PD_TYPE, \
-    	     	A_NULL);      	    	    	    	    	\
-    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## EXTERN_NAME); \
-}   	    	    	    	    	    	    	    	\
-}
-
+    	     	ONE_PD_TYPE, TWO_PD_TYPE, THREE_PD_TYPE, FOUR_PD_TYPE,	\
+    	     	A_NULL);						\
+    SET_HELPSYMBOL(NEW_CLASS, EXTERN_NAME);				\
+    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## EXTERN_NAME);	\
+ }									\
+}									\
+  AUTO_REGISTER_CLASS(NEW_CLASS, SETUP_FUNCTION);
     
 #endif	// for header file
