@@ -5,6 +5,8 @@ LOG
     The state to pass among GEM objects
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -27,6 +29,7 @@ CLASS
 DESCRIPTION
     
 -----------------------------------------------------------------*/
+#define GEMCACHE_MAGIC 0x1234567
 class GEM_EXTERN GemCache
 {
     public:
@@ -39,12 +42,7 @@ class GEM_EXTERN GemCache
     	// Should the image be resent?
     	int 	    	    resendImage;
 
-    	//////////
-    	// The DAG is incorrect and the rendering in the 
-    	//  	chain should stop.
-    	void	    	    breakDAG();
-    	
-        //////////
+	//////////
         // Constructor
     	GemCache(gemhead *parent);
     	
@@ -52,8 +50,16 @@ class GEM_EXTERN GemCache
         // Destructor
         ~GemCache();
 
+	//////////
+	// re-set (like creation, but without instantiating
+	void reset(gemhead*parent);
+
         //////////
     	gemhead     	    *m_parent;
+
+	//////////
+	// indicates a valid cache
+	int m_magic;
 };
 
 #endif	// for header file
