@@ -2,9 +2,11 @@
 LOG
     GEM - Graphics Environment for Multimedia
 
-    create a window
+    get keyboard/mouse/tablet callbacks
 
-    Copyright (c) 1997-1999 Mark Danks.
+    Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -14,6 +16,7 @@ LOG
 #define INCLUDE_GEMEVENT_H_
 
 #include "Base/GemExportDef.h"
+//#include "Base/CPPExtern.h"
 
 //////////////////////////////////////////////////////////////////
 //
@@ -48,6 +51,21 @@ GEM_EXTERN extern void setButtonCallback(BUTTON_CB callback, void *data);
 GEM_EXTERN extern void removeButtonCallback(BUTTON_CB callback, void *data);
 
 
+//////////////////////////////////////////////////////////////////
+//
+// Mouse wheel callback
+//
+//////////////////////////////////////////////////////////////////
+typedef void (*WHEEL_CB)(int, int, void *);
+//////////
+// Set a wheel callback
+GEM_EXTERN extern void setWheelCallback(WHEEL_CB callback, void *data);
+
+//////////
+// Remove a wheel callback
+GEM_EXTERN extern void removeWheelCallback(WHEEL_CB callback, void *data);
+
+
 //////////////////////////////////////////////////////////////////
 //
 // Tablet motion callback
@@ -100,7 +118,7 @@ GEM_EXTERN extern void removeTabletButtonCallback(TABBUTTON_CB callback, void *d
 // Keyboard callback
 //
 //////////////////////////////////////////////////////////////////
-typedef void (*KEYBOARD_CB)(char, int, void *);
+typedef void (*KEYBOARD_CB)(char *,int, int, void *);
 //////////
 // Set a keyboard callback
 GEM_EXTERN extern void setKeyboardCallback(KEYBOARD_CB callback, void *data);
@@ -127,10 +145,11 @@ GEM_EXTERN extern void removeResizeCallback(RESIZE_CB callback, void *data);
 // Trigger an event
 GEM_EXTERN extern void triggerMotionEvent(int x, int y);
 GEM_EXTERN extern void triggerButtonEvent(int which, int state, int x, int y);
+GEM_EXTERN extern void triggerWheelEvent(int axis, int value);
 GEM_EXTERN extern void triggerTabletMotionEvent(int x, int y, float pressure);
 GEM_EXTERN extern void triggerTabletRotationEvent(int az, int alt, int twist);
 GEM_EXTERN extern void triggerTabletButtonEvent(int which, int state, int x, int y);
-GEM_EXTERN extern void triggerKeyboardEvent(char value, int state);
+GEM_EXTERN extern void triggerKeyboardEvent(char *string, int value, int state);
 GEM_EXTERN extern void triggerResizeEvent(int xSize, int ySize);
 
 #endif  // for header file
