@@ -2,11 +2,14 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
+//    Copyright (c) Gnther Geiger.
+//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute
+//
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -22,10 +25,12 @@
 // Constructor
 //
 /////////////////////////////////////////////////////////
-GemGluObj :: GemGluObj(t_floatarg size)
-    	   : GemShape(size), m_numSlices(10), m_thing(NULL)
+GemGluObj :: GemGluObj(t_floatarg size, t_floatarg slices)
+    	   : GemShape(size)
 {
-    m_drawType = (enum GLenum) GLU_FILL;
+    m_drawType = (GLenum) GL_FILL;
+    m_numSlices=(int)slices;
+    if(m_numSlices<=0)m_numSlices=10;
     
     // the number of slices
     m_sliceInlet = inlet_new(this->x_obj, &this->x_obj->ob_pd, gensym("float"), gensym("numslices"));
@@ -38,32 +43,9 @@ GemGluObj :: GemGluObj(t_floatarg size)
 GemGluObj :: ~GemGluObj()
 {
     // in case we are deleted while still running
-    stopRendering();
     inlet_free(m_sliceInlet);
 }
 
-/////////////////////////////////////////////////////////
-// startRendering
-//
-/////////////////////////////////////////////////////////
-void GemGluObj :: startRendering()
-{
-    if (m_thing)
-		stopRendering();
-    m_thing = gluNewQuadric();
-}
-
-/////////////////////////////////////////////////////////
-// stopRendering
-//
-/////////////////////////////////////////////////////////
-void GemGluObj :: stopRendering()
-{
-    if (m_thing)
-		gluDeleteQuadric(m_thing);
-    m_thing = NULL;
-}
-
 /////////////////////////////////////////////////////////
 // numSlicesMess
 //
@@ -81,11 +63,11 @@ void GemGluObj :: numSlicesMess(int numSlices)
 void GemGluObj :: typeMess(t_symbol *type)
 {
     if (!strcmp(type->s_name, "line")) 
-	    m_drawType = (enum GLenum) GLU_LINE;
+	    m_drawType = (GLenum) GL_LINE;
     else if (!strcmp(type->s_name, "fill")) 
-	    m_drawType = (enum GLenum) GLU_FILL;
+	    m_drawType = (GLenum) GL_FILL;
     else if (!strcmp(type->s_name, "point"))
-	    m_drawType = (enum GLenum) GLU_POINT;
+	    m_drawType = (GLenum) GL_POINT;
     else
     {
 	    error ("GEM: GemGluObj draw style");
@@ -107,4 +89,3 @@ void GemGluObj :: numSlicesMessCallback(void *data, t_floatarg numSlices)
 {
     GetMyClass(data)->numSlicesMess((int)numSlices);
 }
-
