@@ -4,7 +4,9 @@ LOG
 
     A Glu object
 
-    Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) 1997-2000 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -13,9 +15,24 @@ LOG
 #ifndef INCLUDE_GEMGLUOBJ_H_
 #define INCLUDE_GEMGLUOBJ_H_
 
-#include "Base/GemShape.h"
+// I hate Microsoft...I shouldn't have to do this!
+#ifdef _WINDOWS
+#include <windows.h>
+#endif
 
-#include <GL/glu.h>
+#include <string.h>
+
+
+#include <math.h>
+#ifndef M_PI
+#  define M_PI (3.1415926)
+#endif
+
+#ifndef GLU_SILHOUETTE
+# define GLU_SILHOUETTE 0
+#endif
+
+#include "Base/GemShape.h"
 
 /*-----------------------------------------------------------------
 -------------------------------------------------------------------
@@ -37,7 +54,7 @@ class GEM_EXTERN GemGluObj : public GemShape
     
 	    //////////
 	    // Constructor
-    	GemGluObj(t_floatarg size);
+  GemGluObj(t_floatarg size, t_floatarg slices=10);
     	
     protected:
     	
@@ -45,14 +62,6 @@ class GEM_EXTERN GemGluObj : public GemShape
     	// Destructor
     	virtual ~GemGluObj();
 
-    	//////////
-    	// Create the quadric
-    	virtual void	startRendering();
-    	
-    	//////////
-    	// Clean it up
-    	virtual void	stopRendering();
-    	
     	//////////
     	// How the object should be drawn
     	virtual void	typeMess(t_symbol *type);
@@ -64,9 +73,6 @@ class GEM_EXTERN GemGluObj : public GemShape
     	//////////
     	// The number of slices
     	int 	    	m_numSlices;
-
-    	//////////
-    	GLUquadricObj 	*m_thing;
     	
         //////////
         t_inlet         *m_sliceInlet;
