@@ -2,16 +2,20 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
+//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute
+//
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
+#ifdef _WINDOWS
+
 #include "GemWinCreate.h"
 
 #include <stdlib.h>
@@ -309,7 +313,7 @@ LONG WINAPI MainWndProc (HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam)
 			if ((int)wParam == VK_CONTROL)
 				ctrlKeyDown = 0;
 
-            triggerKeyboardEvent((int)wParam, 1);
+            triggerKeyboardEvent((char*)&wParam, (int)wParam, 1);
             break;
 
         // keyboard action
@@ -319,7 +323,7 @@ LONG WINAPI MainWndProc (HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam)
 			else if (ctrlKeyDown && (int)wParam == 'R')
 					gemAbortRendering();
 			else
-				triggerKeyboardEvent((int)wParam, 0);
+				triggerKeyboardEvent((char*)&wParam, (int)wParam, 0);
             break;
 
         // resize event
@@ -368,114 +372,174 @@ LONG WINAPI MainWndProc (HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam)
 /////////////////////////////////////////////////////////
 GEM_EXTERN int createGemWindow(WindowInfo &info, WindowHints &hints)
 {
-    static int firstTime = 1;
+  static int firstTime = 1;
     
-    // Register the frame class
-    HINSTANCE hInstance = GetModuleHandle(NULL);
-    if (!hInstance)
+  // Register the frame class
+  HINSTANCE hInstance = GetModuleHandle(NULL);
+  if (!hInstance)
     {
-        error("GEM: Unable to get module instance");
-        return(0);
+      error("GEM: Unable to get module instance");
+      return(0);
     }
-    if (firstTime)
+  if (firstTime)
     {
-        WNDCLASS wndclass;
-        wndclass.style         = 0;
-        wndclass.lpfnWndProc   = (WNDPROC)MainWndProc;
-        wndclass.cbClsExtra    = 0;
-        wndclass.cbWndExtra    = 0;
-        wndclass.hInstance     = hInstance;
-        wndclass.hCursor       = LoadCursor(NULL, IDC_ARROW);
-        wndclass.hIcon         = LoadIcon(NULL, IDI_WINLOGO);
-        wndclass.hbrBackground = NULL;
-        wndclass.lpszMenuName  = NULL;
-        wndclass.lpszClassName = "GEM";
+      WNDCLASS wndclass;
+      wndclass.style         = 0;
+      wndclass.lpfnWndProc   = (WNDPROC)MainWndProc;
+      wndclass.cbClsExtra    = 0;
+      wndclass.cbWndExtra    = 0;
+      wndclass.hInstance     = hInstance;
+      wndclass.hCursor       = LoadCursor(NULL, IDC_CROSS);
+      wndclass.hIcon         = LoadIcon(NULL, IDI_WINLOGO);
+      wndclass.hbrBackground = NULL;
+      wndclass.lpszMenuName  = NULL;
+      wndclass.lpszClassName = "GEM";
 
-        if (!RegisterClass(&wndclass) )
+      if (!RegisterClass(&wndclass) )
         {
-            error("GEM: Unable to register window class");
-            return(0);
+	  error("GEM: Unable to register window class");
+	  return(0);
         }
-        firstTime = 0;
-    }
-	// Since Windows uses some of the window for the border, etc,
-	//		we have to ask how big the window should really be
-	RECT newSize;
-	newSize.left = newSize.top = 0;
-	newSize.right = hints.width;
-	newSize.bottom = hints.height;
-
-	DWORD style = WS_CLIPSIBLINGS | WS_CLIPCHILDREN;
-	if (hints.border)
-		style |= WS_OVERLAPPEDWINDOW;
-	else
-		style |= WS_POPUP;
-
-	AdjustWindowRect(&newSize, style, FALSE); // no menu
-
-    // Create the window
-    info.win = CreateWindow ("GEM",
-             "GEM",
-			 style,
-             0,
-             0,
-             newSize.right,
-             newSize.bottom,
-             NULL,
-             NULL,
-             hInstance,
-             NULL);
-    if (!info.win)
-    {
-        error("GEM: Unable to create window");
-        return(0);
+      firstTime = 0;
     }
 
-	// create the device context
-    info.dc = GetDC(info.win);
-	if (!info.dc)
-	{
-		error("GEM: Unable to create device context");
-		destroyGemWindow(info);
-		return(0);
-	}
+  DWORD dwExStyle=WS_EX_APPWINDOW | WS_EX_WINDOWEDGE;
+  DWORD style = WS_CLIPSIBLINGS | WS_CLIPCHILDREN;
 
-	// set the pixel format for the window
-    if (!bSetupPixelFormat(info.dc, hints))
-    {
-        error("GEM: Unable to set window pixel format");
-		destroyGemWindow(info);
-        return(0);
-    }
+  hints.real_w = hints.width;
+  hints.real_h = hints.height;
 
-	// create the OpenGL context
-    info.context = wglCreateContext(info.dc);
-	if (!info.context)
-	{
-		error("GEM: Unable to create OpenGL context");
-		destroyGemWindow(info);
-		return(0);
-	}
+  int x = hints.x_offset;
+  int y = hints.y_offset;
 
-	// do we share display lists?
-    if (hints.shared) wglShareLists(hints.shared, info.context);
-
-	// make the context the current rendering context
-    if (!wglMakeCurrent(info.dc, info.context))
-	{
-		error("GEM: Unable to make OpenGL context current");
-		destroyGemWindow(info);
-		return(0);
-	}
-
-    if (!hints.actuallyDisplay) return(1);
-
-    // show and update main window
-    ShowWindow(info.win, SW_SHOWNORMAL);
-
-    UpdateWindow(info.win);
+  bool fullscreen=(hints.fullscreen!=0);
+  if (fullscreen){
+    DEVMODE dmScreenSettings;								// Device Mode
     
-    return(1);
+    if (!EnumDisplaySettings(NULL, ENUM_CURRENT_SETTINGS, &dmScreenSettings)){
+      error("GEM: couldn't get screen capabilities!");
+    }
+    int w = dmScreenSettings.dmPelsWidth;
+    int h = dmScreenSettings.dmPelsHeight;
+    
+    x=y=0;
+
+    memset(&dmScreenSettings,0,sizeof(dmScreenSettings));	// Makes Sure Memory's Cleared
+    dmScreenSettings.dmSize=sizeof(dmScreenSettings);		// Size Of The Devmode Structure
+    dmScreenSettings.dmPelsWidth	= hints.width;			// Selected Screen Width
+    dmScreenSettings.dmPelsHeight	= hints.height;			// Selected Screen Height
+    dmScreenSettings.dmBitsPerPel	= 32;					// Selected Bits Per Pixel
+    dmScreenSettings.dmFields=DM_BITSPERPEL|DM_PELSWIDTH|DM_PELSHEIGHT;
+    // Try To Set Selected Mode And Get Results.  NOTE: CDS_FULLSCREEN Gets Rid Of Start Bar.
+    if (ChangeDisplaySettings(&dmScreenSettings,CDS_FULLSCREEN)!=DISP_CHANGE_SUCCESSFUL) {
+      dmScreenSettings.dmPelsWidth	= w;
+      dmScreenSettings.dmPelsHeight	= h;
+      if (ChangeDisplaySettings(&dmScreenSettings,CDS_FULLSCREEN)!=DISP_CHANGE_SUCCESSFUL) {
+	error("GEM: couldn't switch to fullscreen");
+	fullscreen=false;
+      } else {
+	hints.real_h=h;
+	hints.real_w=w;
+      }
+    }
+  }
+  if (fullscreen){
+    dwExStyle  = WS_EX_APPWINDOW;
+    style     |= WS_POPUP;
+  } else {
+    dwExStyle=WS_EX_APPWINDOW | WS_EX_WINDOWEDGE;
+    if (hints.border)
+      style |= WS_OVERLAPPEDWINDOW;
+    else
+      style |= WS_POPUP;
+  }
+
+  info.fs = fullscreen;//hints.fullscreen;
+
+  // Since Windows uses some of the window for the border, etc,
+  //		we have to ask how big the window should really be
+  RECT newSize;
+  newSize.left = x;
+  newSize.top = y;
+  newSize.right = hints.real_w+x;
+  newSize.bottom = hints.real_h+y;
+
+  AdjustWindowRectEx(&newSize, style, FALSE, dwExStyle); // no menu
+
+  if (newSize.left<0 && x>=0){
+	  newSize.right-=newSize.left;
+	  newSize.left=0;
+  }
+  if (newSize.top<0 && y>=0){
+	  newSize.bottom-=newSize.top;
+	  newSize.top=0;
+  }
+
+  // Create the window
+  info.win = CreateWindowEx (
+			     dwExStyle,
+			     "GEM",
+			     hints.title,
+			     style,
+			     newSize.left,
+			     newSize.top,
+			     newSize.right - newSize.left,
+			     newSize.bottom - newSize.top,
+			     NULL,
+			     NULL,
+			     hInstance,
+			     NULL);
+
+  if (!info.win)  {
+      error("GEM: Unable to create window");
+      return(0);
+    }
+
+  // create the device context
+  info.dc = GetDC(info.win);
+  if (!info.dc)  {
+      error("GEM: Unable to create device context");
+      destroyGemWindow(info);
+      return(0);
+    }
+
+  // set the pixel format for the window
+  if (!bSetupPixelFormat(info.dc, hints))  {
+      error("GEM: Unable to set window pixel format");
+      destroyGemWindow(info);
+      return(0);
+    }
+
+  // create the OpenGL context
+  info.context = wglCreateContext(info.dc);
+  if (!info.context)  {
+      error("GEM: Unable to create OpenGL context");
+      destroyGemWindow(info);
+      return(0);
+    }
+
+  // do we share display lists?
+  if (hints.shared) wglShareLists(hints.shared, info.context);
+
+  // make the context the current rendering context
+  if (!wglMakeCurrent(info.dc, info.context))   {
+      error("GEM: Unable to make OpenGL context current");
+      destroyGemWindow(info);
+      return(0);
+    }
+
+  if (!hints.actuallyDisplay) return(1);
+
+  // show and update main window
+  if (fullscreen){
+    ShowWindow(info.win,SW_SHOW);				// Show The Window
+    SetForegroundWindow(info.win);				// Slightly Higher Priority
+    SetFocus(info.win);
+  } else  ShowWindow(info.win, SW_SHOWNORMAL);
+
+  UpdateWindow(info.win);
+
+  return(1);
 }
 
 /////////////////////////////////////////////////////////
@@ -484,19 +548,51 @@ GEM_EXTERN int createGemWindow(WindowInfo &info, WindowHints &hints)
 /////////////////////////////////////////////////////////
 GEM_EXTERN void destroyGemWindow(WindowInfo &info)
 {
-	if (info.win)
-	{
-		if (info.dc)
-		{
-			if (info.context)
-			{
-			    wglDeleteContext(info.context);
-			}
-		    ReleaseDC(info.win, info.dc);
-		}
-	    DestroyWindow(info.win);
-	}
-    info.dc  = NULL;
-	info.win = NULL;
-	info.dc  = NULL;
+  if (info.fs) ChangeDisplaySettings(NULL,0);	// Switch Back To The Desktop
+
+  if (info.win) {
+    if (info.dc) {
+      if (info.context) {
+	wglDeleteContext(info.context);
+      }
+      ReleaseDC(info.win, info.dc);
+    }
+    DestroyWindow(info.win);
+  }
+  info.dc  = NULL;
+  info.win = NULL;
+  info.dc  = NULL;
 }
+
+/////////////////////////////////////////////////////////
+// switch cursor on/off
+//
+/////////////////////////////////////////////////////////
+int cursorGemWindow(WindowInfo &info, int state)
+{
+  static int cursor_state = 1;
+  state=!(!state);
+  if (cursor_state != state){
+    cursor_state=ShowCursor(state)+1;
+  }
+
+  return cursor_state;
+}
+
+/////////////////////////////////////////////////////////
+// set topmost position on/off
+//
+/////////////////////////////////////////////////////////
+int topmostGemWindow(WindowInfo &info, int state)
+{
+  static int topmost_state = 0;
+  state=!(!state);
+  if (state)
+	SetWindowPos(info.win, HWND_TOPMOST, 0, 0, 0, 0, SWP_NOSIZE | SWP_NOMOVE); 
+  else
+	SetWindowPos(info.win, HWND_NOTOPMOST, 0, 0, 0, 0, SWP_NOSIZE | SWP_NOMOVE); 
+  topmost_state = state;
+  return topmost_state;
+}
+
+#endif
