@@ -1,6 +1,9 @@
 #include <stdlib.h>
+#ifdef __APPLE__
+#include "sgiimage.h"
+#else
 #include "Base/sgiimage.h"
-
+#endif // __APPLE__
 /*
  *    	fastimg -
  *		Faster reading and writing of image files.
@@ -24,14 +27,16 @@
 
 #ifndef WIN32
 #include <unistd.h>
-#ifdef linux
-#include <string.h>
-#else
+#ifdef WIN32
 #include <bstring.h>
-#endif	// for linux
+#else
+#include <string.h>
+#endif	// for !linux or !__APPLE__
 #endif	// for !win32
 #include <stdio.h>
 
+
+
 /*
  *	from image.h
  *
@@ -43,13 +48,13 @@ typedef struct {
     unsigned short 	xsize;
     unsigned short 	ysize;
     unsigned short 	zsize;
-    unsigned long 	min;
-    unsigned long 	max;
-    unsigned long	wastebytes;	
+    unsigned int32 	min;
+    unsigned int32 	max;
+    unsigned int32	wastebytes;	
     char 		name[80];
-    unsigned long	colormap;
+    unsigned int32	colormap;
 
-    long 		file;		/* stuff used in core only */
+    int32 		file;		/* stuff used in core only */
     unsigned short 	flags;
     short		dorev;
     short		x;
@@ -59,10 +64,10 @@ typedef struct {
     unsigned short	*ptr;
     unsigned short	*base;
     unsigned short	*tmpbuf;
-    unsigned long	offset;
-    unsigned long	rleend;		/* for rle images */
-    unsigned long	*rowstart;	/* for rle images */
-    long		*rowsize;	/* for rle images */
+    unsigned int32	offset;
+    unsigned int32	rleend;		/* for rle images */
+    unsigned int32	*rowstart;	/* for rle images */
+    int32		*rowsize;	/* for rle images */
 } IMAGE;
 
 #define IMAGIC 	0732
@@ -94,12 +99,12 @@ typedef struct {
 
 #define CHANOFFSET(z)	(3-(z))	/* this is byte order dependent */
 
-static void expandrow(unsigned char *optr, unsigned char *iptr, long z);
-static void setalpha(unsigned char *lptr, long n);
-static void copybw(long *lptr, long n);
-static void lumrow(unsigned char *rgbptr, unsigned char *lumptr, long n); 
-static int compressrow(unsigned char *lbuf, unsigned char *rlebuf, long z, long cnt);
-static void interleaverow(unsigned char *lptr, unsigned char *cptr, long z, long n);
+static void expandrow(unsigned char *optr, unsigned char *iptr, int32 z);
+static void setalpha(unsigned char *lptr, int32 n);
+static void copybw(int32 *lptr, int32 n);
+static void lumrow(unsigned char *rgbptr, unsigned char *lumptr, int32 n); 
+static int compressrow(unsigned char *lbuf, unsigned char *rlebuf, int32 z, int32 cnt);
+static void interleaverow(unsigned char *lptr, unsigned char *cptr, int32 z, int32 n);
 
 #define TAGLEN	(5)
 
@@ -109,7 +114,7 @@ static void interleaverow(unsigned char *lptr, unsigned char *cptr, long z, long
  *
  */
 #ifdef WIN32
-static void bzero(void *ptr, long size)
+static void bzero(void *ptr, int32 size)
 {
 	unsigned char *cptr = (unsigned char *) ptr;
 	for (; size != 0; size--)
@@ -117,14 +122,14 @@ static void bzero(void *ptr, long size)
 }
 #endif
 
-unsigned long *
-getLongImage(char *textureFile, long *xsize, long *ysize, long *csize)
+unsigned int32 *
+getLongImage(char *textureFile, int32 *xsize, int32 *ysize, int32 *csize)
 {
     sizeofimage(textureFile, xsize, ysize, csize);
     return longimagedata(textureFile);
 }
 
-void addlongimgtag(unsigned long *dptr, long xsize, long ysize)
+void addlongimgtag(unsigned int32 *dptr, int32 xsize, int32 ysize)
 {
     dptr = dptr+(xsize*ysize);
     dptr[0] = 0x12345678;
@@ -146,7 +151,7 @@ static unsigned short getshort(FILE *inf)
     return (buf[0]<<8)+(buf[1]<<0);
 }
 
-static unsigned long getlong(FILE *inf)
+static unsigned int32 getlong(FILE *inf)
 {
     unsigned char buf[4];
 
@@ -163,7 +168,7 @@ static void putshort(FILE *outf, unsigned short val)
     fwrite(buf,2,1,outf);
 }
 
-static int putlong(FILE *outf, unsigned long val)
+static int putlong(FILE *outf, unsigned int32 val)
 {
     unsigned char buf[4];
 
@@ -204,9 +209,9 @@ static int writeheader(FILE *outf, IMAGE *image)
     return fwrite("no name",8,1,outf);
 }
 
-static int writetab(FILE *outf, unsigned long *tab, long len)
+static int writetab(FILE *outf, unsigned int32 *tab, int32 len)
 {
-    int r;
+    int r=0;
 
     while(len) {
 	r = putlong(outf,*tab++);
@@ -215,7 +220,7 @@ static int writetab(FILE *outf, unsigned long *tab, long len)
     return r;
 }
 
-static void readtab(FILE *inf, unsigned long *tab, long len)
+static void readtab(FILE *inf, unsigned int32 *tab, int32 len)
 {
     while(len) {
 	*tab++ = getlong(inf);
@@ -228,7 +233,7 @@ static void readtab(FILE *inf, unsigned long *tab, long len)
  *		return the xsize and ysize of an iris image file.
  *
  */
-int sizeofimage(char *name, long *xsize, long *ysize, long *csize)
+int sizeofimage(char *name, int32 *xsize, int32 *ysize, int32 *csize)
 {
     IMAGE image;
     FILE *inf;
@@ -258,11 +263,11 @@ int sizeofimage(char *name, long *xsize, long *ysize, long *csize)
  *	pointer to an array of longs.
  *
  */
-unsigned long *longimagedata(char *name)
+unsigned int32 *longimagedata(char *name)
 {
-    unsigned long *base, *lptr;
+    unsigned int32 *base, *lptr;
     unsigned char *rledat, *verdat;
-    unsigned long *starttab, *lengthtab;
+    unsigned int32 *starttab, *lengthtab;
     FILE *inf;
     IMAGE *image;
     int y, z, tablen;
@@ -296,10 +301,10 @@ unsigned long *longimagedata(char *name)
     zsize = image->zsize;
     if(rle)
 	{
-		tablen = ysize*zsize*sizeof(long);
-		starttab = (unsigned long *)malloc(tablen);
-		lengthtab = (unsigned long *)malloc(tablen);
-		rlebuflen = (long)(1.05*xsize+10);
+		tablen = ysize*zsize*sizeof(int32);
+		starttab = (unsigned int32 *)malloc(tablen);
+		lengthtab = (unsigned int32 *)malloc(tablen);
+		rlebuflen = (int32)(1.05*xsize+10);
 		rledat = (unsigned char *)malloc(rlebuflen);
 		fseek(inf,512,SEEK_SET);
  		readtab(inf,starttab,tablen);
@@ -325,8 +330,8 @@ unsigned long *longimagedata(char *name)
 
 		fseek(inf,512+2*tablen,SEEK_SET);
 		cur = 512+2*tablen;
-		base = (unsigned long *)
-			malloc((xsize*ysize+TAGLEN)*sizeof(long));
+		base = (unsigned int32 *)
+			malloc((xsize*ysize+TAGLEN)*sizeof(int32));
 		addlongimgtag(base,xsize,ysize);
 
   		if(badorder)
@@ -343,9 +348,9 @@ unsigned long *longimagedata(char *name)
 					}
 					if(lengthtab[y+z*ysize]>rlebuflen)
 					{
-						fprintf(stderr,"longimagedata: rlebuf(%d) is too small - bad poop : %d\n"
-								,rlebuflen, lengthtab[y+z*ysize]);
-						return(NULL);
+					     fprintf(stderr,"longimagedata: rlebuf(%d) is too small - bad poop : %d\n"
+						     ,rlebuflen, lengthtab[y+z*ysize]);
+					     return(NULL);
 					}
 					fread(rledat,lengthtab[y+z*ysize],1,inf);
 					cur += lengthtab[y+z*ysize];
@@ -384,7 +389,7 @@ unsigned long *longimagedata(char *name)
 		if(zsize == 3) 
 			setalpha((unsigned char *)base,xsize*ysize);
 		else if(zsize<3) 
-			copybw((long *)base,xsize*ysize);
+			copybw((int32 *)base,xsize*ysize);
 		fclose(inf);
 		free(starttab);
 		free(lengthtab);
@@ -394,8 +399,8 @@ unsigned long *longimagedata(char *name)
     }
 	else
 	{
-		base = (unsigned long *)
-			malloc((xsize*ysize+TAGLEN)*sizeof(long));
+		base = (unsigned int32 *)
+			malloc((xsize*ysize+TAGLEN)*sizeof(int32));
 		addlongimgtag(base,xsize,ysize);
 		verdat = (unsigned char *)malloc(xsize);
 		fseek(inf,512,SEEK_SET);
@@ -416,7 +421,7 @@ unsigned long *longimagedata(char *name)
 		if(zsize == 3) 
 			setalpha((unsigned char *)base,xsize*ysize);
 		else if(zsize<3) 
-			copybw((long *)base,xsize*ysize);
+			copybw((int32 *)base,xsize*ysize);
 		fclose(inf);
 		free(verdat);
 		free(image);
@@ -426,7 +431,7 @@ unsigned long *longimagedata(char *name)
 
 /* static utility functions for longimagedata */
 
-static void interleaverow(unsigned char *lptr, unsigned char *cptr, long z, long n)
+static void interleaverow(unsigned char *lptr, unsigned char *cptr, int32 z, int32 n)
 {
     lptr += z;
     while(n--) {
@@ -435,7 +440,7 @@ static void interleaverow(unsigned char *lptr, unsigned char *cptr, long z, long
     }
 }
 
-static void copybw(long *lptr, long n)
+static void copybw(int32 *lptr, int32 n)
 {
     while(n>=8) {
 	lptr[0] = 0xff000000+(0x010101*(lptr[0]&0xff));
@@ -455,7 +460,7 @@ static void copybw(long *lptr, long n)
     }
 }
 
-static void setalpha(unsigned char *lptr, long n)
+static void setalpha(unsigned char *lptr, int32 n)
 {
 #ifndef IRISGL
 	lptr +=3;
@@ -478,7 +483,7 @@ static void setalpha(unsigned char *lptr, long n)
     }
 }
 
-static void expandrow(unsigned char *optr, unsigned char *iptr, long z)
+static void expandrow(unsigned char *optr, unsigned char *iptr, int32 z)
 {
     unsigned char pixel, count;
 
@@ -527,6 +532,7 @@ static void expandrow(unsigned char *optr, unsigned char *iptr, long z)
     }
 }
 
+
 /*
  *	longstoimage -
  *		copy an array of longs to an iris image file.  Each long
@@ -538,14 +544,14 @@ static void expandrow(unsigned char *optr, unsigned char *iptr, long z)
  *	RGBA image file is saved.
  *
  */
-int longstoimage(unsigned long *lptr, long xsize, long ysize, long zsize, char *name)
+int longstoimage(unsigned int32 *lptr, int32 xsize, int32 ysize, int32 zsize, char *name)
 {
     FILE *outf;
     IMAGE *image;
     int tablen, y, z, pos, len;
-    long *starttab, *lengthtab;
+    int32 *starttab, *lengthtab;
     unsigned char *rlebuf;
-    unsigned long *lumbuf;
+    unsigned int32 *lumbuf;
     int rlebuflen, goodwrite;
 
     goodwrite = 1;
@@ -554,14 +560,14 @@ int longstoimage(unsigned long *lptr, long xsize, long ysize, long zsize, char *
 	fprintf(stderr,"longstoimage: can't open output file\n");
 	return 0;
     }
-    tablen = ysize*zsize*sizeof(long);
+    tablen = ysize*zsize*sizeof(int32);
 
     image = (IMAGE *)malloc(sizeof(IMAGE));
-    starttab = (long *)malloc(tablen);
-    lengthtab = (long *)malloc(tablen);
-    rlebuflen = (long)(1.05*xsize+10);
+    starttab = (int32 *)malloc(tablen);
+    lengthtab = (int32 *)malloc(tablen);
+    rlebuflen = (int32)(1.05*xsize+10);
     rlebuf = (unsigned char *)malloc(rlebuflen);
-    lumbuf = (unsigned long *)malloc(xsize*sizeof(long));
+    lumbuf = (unsigned int32 *)malloc(xsize*sizeof(int32));
 
     bzero(image,sizeof(IMAGE));
     image->imagic = IMAGIC; 
@@ -607,8 +613,8 @@ int longstoimage(unsigned long *lptr, long xsize, long ysize, long zsize, char *
     }
 
     fseek(outf,512,SEEK_SET);
-    goodwrite *= writetab(outf,(unsigned long *)starttab,tablen);
-    goodwrite *= writetab(outf,(unsigned long *)lengthtab,tablen);
+    goodwrite *= writetab(outf,(unsigned int32 *)starttab,tablen);
+    goodwrite *= writetab(outf,(unsigned int32 *)lengthtab,tablen);
     free(image);
     free(starttab);
     free(lengthtab);
@@ -625,7 +631,7 @@ int longstoimage(unsigned long *lptr, long xsize, long ysize, long zsize, char *
 
 /* static utility functions for longstoimage */
 
-static void lumrow(unsigned char *rgbptr, unsigned char *lumptr, long n) 
+static void lumrow(unsigned char *rgbptr, unsigned char *lumptr, int32 n) 
 {
     lumptr += CHANOFFSET(0);
     while(n--) {
@@ -635,11 +641,11 @@ static void lumrow(unsigned char *rgbptr, unsigned char *lumptr, long n)
     }
 }
 
-static int compressrow(unsigned char *lbuf, unsigned char *rlebuf, long z, long cnt)
+static int compressrow(unsigned char *lbuf, unsigned char *rlebuf, int32 z, int32 cnt)
 {
     unsigned char *iptr, *ibufend, *sptr, *optr;
     short todo, cc;							
-    long count;
+    int32 count;
 
     lbuf += z;
     iptr = lbuf;
