@@ -2,11 +2,13 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
+//    Copyright (c) Gnther Geiger.
+//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -36,7 +38,6 @@ render_trigger :: render_trigger()
 /////////////////////////////////////////////////////////
 render_trigger :: ~render_trigger()
 {
-    outlet_free(m_out1);
     outlet_free(m_preOut);
     outlet_free(m_postOut);
 }
