@@ -5,6 +5,8 @@ LOG
     A colorSquare
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -52,10 +54,6 @@ class GEM_EXTERN colorSquare : public GemShape
     	// After rendering
     	virtual void 	postrender(GemState *state);
 
-    	//////////
-    	// How the object should be drawn
-    	virtual void	typeMess(t_symbol *type);
-
     	//////////
     	// Set the individual color vertices
         void            vertColorMess(int whichVert, float r, float g, float b);
