@@ -5,6 +5,8 @@ LOG
     A cube
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -14,6 +16,7 @@ LOG
 #define INCLUDE_CUBE_H_
 
 #include "Base/GemShape.h"
+#include <string.h>
 
 /*-----------------------------------------------------------------
 -------------------------------------------------------------------
@@ -47,10 +50,13 @@ class GEM_EXTERN cube : public GemShape
     	//////////
     	// Do the rendering
     	virtual void 	render(GemState *state);
-
-    	//////////
-    	// How the object should be drawn
-    	virtual void	typeMess(t_symbol *type);
+	
+	int	m_blend;
+	
+    private:
+    //////////
+    // Static member functions
+    static void 	blendMessCallback(void *data, t_floatarg size);
 };
 
 #endif	// for header file
