@@ -2,9 +2,11 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
-//    Copyright (c) 1997-1999 Mark Danks.
+//    Copyright (c) 1997-2000 Mark Danks.
+//    Copyright (c) Gnther Geiger.
+//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -29,6 +31,11 @@ curve :: curve(t_floatarg numInputs)
 {
     m_drawType = GL_LINE_STRIP;
     m_resolution = 30;
+
+    m_texCoords[0][0]=0;m_texCoords[0][1]=0;
+    m_texCoords[1][0]=1;m_texCoords[1][1]=0;
+    m_texCoords[2][0]=0;m_texCoords[2][1]=1;
+    m_texCoords[3][0]=1;m_texCoords[3][1]=1;
 }
 
 /////////////////////////////////////////////////////////
@@ -42,10 +49,19 @@ curve :: ~curve()
 // render
 //
 /////////////////////////////////////////////////////////
-void curve :: render(GemState *)
+void curve :: render(GemState *state)
 {
-    glNormal3d(0.0, 0.0, 1.0);
+    glNormal3f(0.0f, 0.0f, 1.0f);
     glLineWidth(m_linewidth);
+    if(state->texture){
+      m_texCoords[0][0]=state->texCoords[0].s;m_texCoords[0][1]=state->texCoords[0].t;
+      m_texCoords[1][0]=state->texCoords[1].s;m_texCoords[1][1]=state->texCoords[1].t;
+      m_texCoords[2][0]=state->texCoords[2].s;m_texCoords[2][1]=state->texCoords[2].t;
+      m_texCoords[3][0]=state->texCoords[3].s;m_texCoords[3][1]=state->texCoords[3].t;
+
+      glEnable(GL_MAP1_TEXTURE_COORD_2);
+      glMap1f(GL_MAP1_TEXTURE_COORD_2, 0,   1,   2, m_numInputs, &m_texCoords[0][0]);
+    }
     glMap1f(GL_MAP1_VERTEX_3, 0.0, 1.0, 3, m_numInputs, &(m_vert[0][0]));
     glEnable(GL_MAP1_VERTEX_3);
     glBegin(m_drawType);
@@ -65,24 +81,6 @@ void curve :: resolutionMess(int resolution)
     setModified();
 }
 
-/////////////////////////////////////////////////////////
-// typeMess
-//
-/////////////////////////////////////////////////////////
-void curve :: typeMess(t_symbol *type)
-{
-    if (!strcmp(type->s_name, "line")) 
-	    m_drawType = GL_LINE_STRIP;
-    else if (!strcmp(type->s_name, "point"))
-	    m_drawType = GL_POINTS;
-    else
-    {
-	    error("GEM: curve draw style");
-	    return;
-    }
-    setModified();
-}
-
 /////////////////////////////////////////////////////////
 // static member function
 //
