@@ -5,6 +5,9 @@ LOG
     map an image to polygons
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) 2002 James Tittle & Chris Clepper
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -61,6 +64,12 @@ class GEM_EXTERN imageVert : public GemPixObj
 		// [in] texture - Is texture mapping turned on?
     	virtual void 	processGrayPix(imageStruct &image, int texture);
 
+    	//////////
+    	// Do the processing for YUV image
+		// [in] image - The image to use
+		// [in] texture - Is texture mapping turned on?
+    	virtual void 	processYUVPix(imageStruct &image, int texture);
+        
     	//////////
     	// Do the rendering.
     	virtual void 	render(GemState *state);
