@@ -5,6 +5,8 @@ LOG
     A text3d
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -15,8 +17,9 @@ LOG
 
 #include "Base/TextBase.h"
 
-class GLTTFont;
-class FTFace;
+#ifdef GLTT
+#include "GLTTFont.h"
+#endif
 
 /*-----------------------------------------------------------------
 -------------------------------------------------------------------
@@ -44,37 +47,19 @@ class GEM_EXTERN text3d : public TextBase
     	// Destructor
     	virtual ~text3d();
 
-    	//////////
-    	// Do the rendering
-    	virtual void 	render(GemState *state);
-
-    	//////////
-    	// The font to use
-    	virtual void   	fontNameMess(const char *filename);
-
-		//////////
-		// Create the actual font from the face
-		int				makeFontFromFace();
-
-		//////////
-		// Set the font size
-		virtual void	setFontSize(int size);
-
-		//////////
-		// Set the precision for rendering
-		virtual void	setPrecision(float prec);
-
-	    //-----------------------------------
-	    // GROUP:	Member variables
-	    //-----------------------------------
-    
-	   	//////////
+#ifdef FTGL
+	virtual FTFont*makeFont(const char*fontname);
+#elif defined GLTT
+	virtual int     makeFontFromFace();
+	virtual void    destroyFont();
+	//////////
     	// The font structure
     	GLTTFont		*m_font;
 
     	//////////
-    	// The font structure
-    	FTFace 			*m_face;
+    	// Do the rendering
+    	virtual void 	render(GemState *state);
+#endif
 };
 
 #endif	// for header file
