@@ -2,17 +2,20 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
 // Implementation file
 //
-//    Copyright (c) 1997-1999 Mark Danks.
+//    Copyright (c) 1997-2000 Mark Danks.
+//    Copyright (c) Gnther Geiger.
+//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
 /////////////////////////////////////////////////////////
 
 #include "triangle.h"
+#include <string.h>
 
 #include "Base/GemState.h"
 
@@ -45,7 +48,7 @@ triangle :: ~triangle()
 /////////////////////////////////////////////////////////
 void triangle :: render(GemState *state)
 {
-    glNormal3d(0.0, 0.0, 1.0);
+    glNormal3f(0.0f, 0.0f, 1.0f);
     if (m_drawType == GL_LINE_LOOP)
         glLineWidth(m_linewidth);
 
@@ -77,26 +80,6 @@ void triangle :: render(GemState *state)
         glLineWidth(1.0);
 }
 
-/////////////////////////////////////////////////////////
-// typeMess
-//
-/////////////////////////////////////////////////////////
-void triangle :: typeMess(t_symbol *type)
-{
-    if (!strcmp(type->s_name, "line")) 
-	    m_drawType = GL_LINE_LOOP;
-    else if (!strcmp(type->s_name, "fill")) 
-	    m_drawType = GL_TRIANGLES;
-    else if (!strcmp(type->s_name, "point"))
-	    m_drawType = GL_POINTS;
-    else
-    {
-	    error ("GEM: triangle: draw style");
-	    return;
-    }
-    setModified();
-}
-
 /////////////////////////////////////////////////////////
 // static member function
 //
