@@ -4,7 +4,9 @@ LOG
 
     A triangle
 
-    Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) 1997-2000 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -47,10 +49,6 @@ class GEM_EXTERN triangle : public GemShape
     	//////////
     	// Do the rendering
     	virtual void 	render(GemState *state);
-
-    	//////////
-    	// How the object should be drawn
-    	virtual void	typeMess(t_symbol *type);
 };
 
 #endif	// for header file
