@@ -2,11 +2,13 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
 // Implementation file
 //
-//    Copyright (c) 1997-1999 Mark Danks.
+//    Copyright (c) 1997-2000 Mark Danks.
+//    Copyright (c) Gnther Geiger.
+//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -76,6 +78,8 @@ void color :: colorMess(float red, float green, float blue, float alpha)
 /////////////////////////////////////////////////////////
 void color :: obj_setupCallback(t_class *classPtr)
 {
+  class_addcreator((t_newmethod)_classcolor, 
+		   gensym("colour"), A_GIMME, A_NULL);
     class_addmethod(classPtr, (t_method)&color::colorMessCallback,
     	    gensym("color"), A_GIMME, A_NULL); 
 }
