@@ -2,11 +2,13 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
+//    Copyright (c) Gnther Geiger.
+//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -125,6 +127,8 @@ void colorRGB :: aMess(float val)
 /////////////////////////////////////////////////////////
 void colorRGB :: obj_setupCallback(t_class *classPtr)
 {
+  class_addcreator((t_newmethod)_classcolorRGB, 
+		   gensym("colourRGB"), A_GIMME, A_NULL);
     class_addmethod(classPtr, (t_method)&colorRGB::rMessCallback,
     	    gensym("rVal"), A_FLOAT, A_NULL); 
     class_addmethod(classPtr, (t_method)&colorRGB::gMessCallback,
