@@ -2,11 +2,13 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
+//    Copyright (c) Gnther Geiger.
+//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -58,7 +60,7 @@ void separator :: render(GemState *state)
     m_state.image   	 = state->image;
     m_state.numTexCoords = state->numTexCoords;
     
-    delete [] m_state.texCoords;
+    if(m_state.texCoords)delete [] m_state.texCoords;
     if (state->texCoords)
     {
     	m_state.texCoords = new TexCoord[m_state.numTexCoords];
@@ -90,8 +92,10 @@ void separator :: postrender(GemState *state)
     state->texture  	= m_state.texture;
     state->image    	= m_state.image;
     state->numTexCoords = m_state.numTexCoords;
-
-    delete [] state->texCoords;
+#ifdef CRASH
+    post("likely to crash:"); // do we have a memory hole without ? i think so...
+    if (state->texCoords)delete [] (state->texCoords);
+#endif
     if (m_state.texCoords)
     {
     	state->texCoords = new TexCoord[m_state.numTexCoords];
