@@ -4,6 +4,12 @@
  * WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
  */
 
+#ifdef NT
+#pragma warning( disable : 4244 )
+#pragma warning( disable : 4305 )
+#pragma warning( disable : 4091 )
+#endif
+
 #include "m_pd.h"
 #include <math.h>
 
@@ -17,7 +23,7 @@ typedef struct _abs
 
 static t_int *abs_perform(t_int *w)
 {
-    t_abs *x = (t_abs *)(w[1]);
+    //t_abs *x = (t_abs *)(w[1]);
     t_float *in = (t_float *)(w[2]);
     t_float *out = (t_float *)(w[3]);
     int n = (int)(w[4]);
