@@ -2,11 +2,13 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
+//    Copyright (c) Gnther Geiger.
+//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -16,6 +18,10 @@
 
 #include "Base/GemMan.h"
 
+#ifdef __APPLE__
+extern bool HaveValidContext (void);
+#endif
+
 CPPEXTERN_NEW_WITH_ONE_ARG(world_light, t_floatarg, A_DEFFLOAT)
 
 /////////////////////////////////////////////////////////
@@ -55,9 +61,16 @@ world_light :: world_light(t_floatarg lightNum)
 /////////////////////////////////////////////////////////
 world_light :: ~world_light()
 {
-	stopRendering();
+#ifdef __APPLE__
+    if ( !HaveValidContext () ){
+	if (m_light)
+	    GemMan::freeLight(m_light);
+	return;
+    }
+#endif
+    stopRendering();
     if (m_light)
-		GemMan::freeLight(m_light);
+	GemMan::freeLight(m_light);
 }
 
 /////////////////////////////////////////////////////////
@@ -105,7 +118,7 @@ void world_light :: startRendering()
 		stopRendering();
     m_thing = gluNewQuadric();
 	gluQuadricTexture(m_thing, GL_FALSE);
-	gluQuadricDrawStyle(m_thing,(enum GLenum) GLU_FILL);
+	gluQuadricDrawStyle(m_thing, (GLenum) GLU_FILL);
 	m_change = 1;
 }
 
@@ -115,6 +128,12 @@ void world_light :: startRendering()
 /////////////////////////////////////////////////////////
 void world_light :: stopRendering()
 {
+#ifdef __APPLE__
+  if (!HaveValidContext ()) {
+    post("GEM: world_light: need context to call glDisable");
+    return;
+  }
+#endif
     if (m_thing)
 		gluDeleteQuadric(m_thing);
     m_thing = NULL;
