@@ -5,6 +5,9 @@ LOG
     Change pix to greyscale
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) 2002 James Tittle & Chris Clepper
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -46,8 +49,11 @@ class GEM_EXTERN pix_2grey : public GemPixObj
 
     	//////////
     	// Do the processing
-    	virtual void 	processImage(imageStruct &image);
-
+    	virtual void 	processRGBAImage(imageStruct &image);
+        virtual void 	processRGBAltivec(imageStruct &image);
+	virtual void 	processYUVImage(imageStruct &image);
+        virtual void 	processYUVAltivec(imageStruct &image);
+     	    	  
     	//////////
     	// Do the processing - this is a no-op
     	virtual void 	processGrayImage(imageStruct &image) { }
