@@ -2,9 +2,11 @@
 LOG
     GEM - Graphics Environment for Multimedia
 
-    A pix_buf
+    buffer a pixBlock
 
-    Copyright (c) 1997-1998 Mark Danks
+    Copyright (c) 1997-1998 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -42,7 +44,7 @@ class GEM_EXTERN pix_buf : public GemBase
 
 	    //////////
 	    // Constructor
-    	pix_buf();
+    	pix_buf(t_floatarg);
     	
     protected:
     	
@@ -68,13 +70,26 @@ class GEM_EXTERN pix_buf : public GemBase
     	// Clean everything up
     	void	    	cleanImage();
     	   	
-    	//////////
-    	// The buffered block
-    	pixBlock    	m_pixBlock;
-    	
-    	//////////
-    	// The old cache
-    	GemCache    	*m_oldcache;
+	//////////
+	// the pixBlock-cache
+	pixBlock    cachedPixBlock;
+	pixBlock    *orgPixBlock;
+
+	//////////
+	// force output of the buffer:
+	void            bangMess();
+	bool            m_banged;
+	
+	void            autoMess(int);
+	bool            m_auto;
+
+
+private:
+	
+	//////////
+	// Static member callbacks
+	static void bangMessCallback(void *);
+	static void autoMessCallback(void *, t_floatarg);
 };
 
 #endif	// for header file
