@@ -5,6 +5,8 @@ LOG
     Composite two pix images.
 
     Copyright (c) 1997-1998 Mark Danks
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -35,19 +37,20 @@ class GEM_EXTERN pix_composite : public GemPixDualObj
 
     public:
 
-	    //////////
-	    // Constructor
-    	pix_composite();
+    //////////
+    // Constructor
+    pix_composite();
     	
-    protected:
+ protected:
     	
-    	//////////
-    	// Destructor
-    	virtual ~pix_composite();
+    //////////
+    // Destructor
+    virtual ~pix_composite();
 
-    	//////////
-    	// Do the processing
-    	virtual void 	processDualImage(imageStruct &image, imageStruct &right);
+    //////////
+    // Do the processing
+    virtual void 	processRGBA_RGBA(imageStruct &image, imageStruct &right);
+    virtual void 	processRGBA_Gray(imageStruct &image, imageStruct &right);
 };
 
 #endif	// for header file
