@@ -2,11 +2,13 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
 // Implementation file
 //
 //    Copyright (c) 1997-1998 Mark Danks.
+//    Copyright (c) Gnther Geiger.
+//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -39,7 +41,7 @@ pix_coordinate :: pix_coordinate()
 /////////////////////////////////////////////////////////
 pix_coordinate :: ~pix_coordinate()
 {
-    delete [] m_coords;
+    if(m_coords)delete [] m_coords;
 }
 
 /////////////////////////////////////////////////////////
@@ -78,14 +80,13 @@ void pix_coordinate :: coordsMess(int argc, t_atom *argv)
     
     if (numVals != m_numCoords)
     {
-    	delete [] m_coords;
-    	m_numCoords = numVals;
-    	if (m_numCoords == 0)
-    	{
-    	    m_coords = NULL;
-    	    return;
-    	}
-    	m_coords = new TexCoord[m_numCoords];
+      if(m_coords)delete [] m_coords;
+      m_numCoords = numVals;
+      if (m_numCoords == 0)    	{
+	m_coords = NULL;
+	return;
+      }
+      m_coords = new TexCoord[m_numCoords];
     }
     
     for (int i = 0; i < numVals; i++)
