@@ -2,11 +2,13 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
+//    Copyright (c) Gnther Geiger.
+//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -21,13 +23,6 @@
 
 #include "Base/GemCache.h"
 
-static inline int powerOfTwo(int value)
-{
-    int x = 1;
-    while(x < value) x <<= 1;
-    return(x);
-}
-
 CPPEXTERN_NEW_WITH_ONE_ARG(pix_image, t_symbol *, A_DEFSYM)
 
 pix_image::singleImageCache *pix_image::s_imageCache = NULL;
@@ -43,8 +38,9 @@ pix_image::singleImageCache *pix_image::s_imageCache = NULL;
 pix_image :: pix_image(t_symbol *filename)
     	   : m_loadedImage(NULL)
 {
-    // make sure that there are some characters
-    if (filename->s_name[0]) openMess(filename);
+  m_pixBlock.image = m_imageStruct;
+  // make sure that there are some characters
+  if (filename->s_name[0]) openMess(filename);
 }
 
 /////////////////////////////////////////////////////////
@@ -63,7 +59,10 @@ pix_image :: ~pix_image()
 void pix_image :: openMess(t_symbol *filename)
 {
     cleanImage();
-    
+
+    if (m_cache&&m_cache->m_magic!=GEMCACHE_MAGIC)
+      m_cache=NULL;    
+
     // is the image already loaded?
     singleImageCache *cache = s_imageCache;
     int found = 0;
@@ -76,10 +75,11 @@ void pix_image :: openMess(t_symbol *filename)
     // yep, we have it
     if (found)
     {
+      //post("using cached image");
         m_loadedImage = cache;
         m_loadedImage->refCount++;
         strcpy(m_filename, filename->s_name);
-        copy2Image(&(m_pixBlock.image), m_loadedImage->image);
+        m_loadedImage->image->copy2Image(&m_pixBlock.image);
         m_pixBlock.newimage = 1;
         if (m_cache) m_cache->resendImage = 1;
         return;
@@ -108,15 +108,9 @@ void pix_image :: openMess(t_symbol *filename)
         while(ptr->next) ptr = ptr->next;
         ptr->next = m_loadedImage;
     }
-
-    copy2Image(&(m_pixBlock.image), m_loadedImage->image);
+    m_loadedImage->image->copy2Image(&m_pixBlock.image);
     m_pixBlock.newimage = 1;
     post("GEM: loaded image: %s", buf);
-	if (powerOfTwo(m_pixBlock.image.xsize) != m_pixBlock.image.xsize ||
-		powerOfTwo(m_pixBlock.image.ysize) != m_pixBlock.image.ysize)
-	{
-		error("GEM: pix_image: image size not a power of 2: %s", buf);
-	}
 }
 
 /////////////////////////////////////////////////////////
@@ -127,15 +121,13 @@ void pix_image :: render(GemState *state)
 {
     // if we don't have an image, just return
     if (!m_loadedImage) return;
-    
     // do we need to reload the image?    
-    if (m_cache->resendImage)
+    if (m_cache&&m_cache->resendImage)
     {
-	    refreshImage(&(m_pixBlock.image), m_loadedImage->image);
+      m_loadedImage->image->refreshImage(&m_pixBlock.image);
     	m_pixBlock.newimage = 1;
     	m_cache->resendImage = 0;
     }
-    
     state->image = &m_pixBlock;
 }
 
@@ -145,8 +137,8 @@ void pix_image :: render(GemState *state)
 /////////////////////////////////////////////////////////
 void pix_image :: postrender(GemState *state)
 {
-    m_pixBlock.newimage = 0;
-    state->image = NULL;
+  m_pixBlock.newimage = 0;
+  state->image = NULL;
 }
 
 /////////////////////////////////////////////////////////
@@ -156,8 +148,7 @@ void pix_image :: postrender(GemState *state)
 void pix_image :: startRendering()
 {
     if (!m_loadedImage) return;
-
-    refreshImage(&(m_pixBlock.image), m_loadedImage->image);
+    m_loadedImage->image->refreshImage(&m_pixBlock.image);
     m_pixBlock.newimage = 1;
 }
 
@@ -193,7 +184,7 @@ void pix_image :: cleanImage()
         }
 	    m_loadedImage = NULL;
 
-    	delete [] m_pixBlock.image.data;
+    	m_pixBlock.image.clear();
         m_pixBlock.image.data = NULL;
     }
 }
@@ -204,6 +195,7 @@ void pix_image :: cleanImage()
 /////////////////////////////////////////////////////////
 void pix_image :: clickMess()
 {
+  post("pix_image: clicked");
     if (!m_loadedImage) return;
 
     // fork to display an image
