@@ -5,6 +5,8 @@ LOG
     Load an image into a pix block
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -53,7 +55,6 @@ class GEM_EXTERN pix_image : public GemBase
                         { imageName = strdup(_imageName); }
                 ~singleImageCache()
                             { delete imageName;
-                              if (image) delete [] image->data;
                               delete image;
                             }
                 int                 refCount;
@@ -105,6 +106,9 @@ class GEM_EXTERN pix_image : public GemBase
     	//////////
     	// The pixBlock with the current image
     	pixBlock    	m_pixBlock;
+	//////////
+	// The current image
+	imageStruct     m_imageStruct;
     	
     	//////////
     	char	    	m_filename[80];
