@@ -5,6 +5,9 @@ LOG
     Do a blue screen with pix images.
 
     Copyright (c) 1997-1998 Mark Danks
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) 2002 James Tittle & Chris Clepper
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -46,12 +49,12 @@ class GEM_EXTERN pix_mask : public GemPixDualObj
 
     	//////////
     	// Do the processing
-    	virtual void 	processDualImage(imageStruct &image, imageStruct &right);
+    	virtual void 	processRGBA_RGBA(imageStruct &image, imageStruct &right);
 
     	//////////
     	//  This is called whenever a new image comes through.
-		//	The left image is an RGBA, the right is a gray8
-    	virtual void 	processRightGray(imageStruct &image, imageStruct &right); 	
+        //	The left image is an RGBA, the right is a gray8
+    	virtual void 	processRGBA_Gray(imageStruct &image, imageStruct &right);
 };
 
 #endif	// for header file
