@@ -2,11 +2,13 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
+//    Copyright (c) Gnther Geiger.
+//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -33,20 +35,18 @@ pix_multiimage::multiImageCache *pix_multiimage::s_imageCache = NULL;
 pix_multiimage :: pix_multiimage(t_symbol *filename, t_floatarg baseImage, t_floatarg topImage, t_floatarg skipRate)
     	    	: m_numImages(0), m_curImage(-1), m_loadedCache(NULL)
 {
-    inlet_new(this->x_obj, &this->x_obj->ob_pd, gensym("float"), gensym("img_num"));
+  inlet_new(this->x_obj, &this->x_obj->ob_pd, gensym("float"), gensym("img_num"));
+  m_pixBlock.image = m_imageStruct;
 
-    // make sure that there are some characters
-    if (filename->s_name[0])
-    { 
-        if (skipRate == 0)
-        {
-            if (topImage == 0)
-                openMess(filename, 0, (int)baseImage, 1);
-            else
-                openMess(filename, (int)baseImage, (int)topImage, 1);
-        }
-        else openMess(filename, (int)baseImage, (int)topImage, (int)skipRate);
-    }
+  // make sure that there are some characters
+  if (filename->s_name[0]) { 
+    if (skipRate == 0)  {
+      if (topImage == 0)
+	openMess(filename, 0, (int)baseImage, 1);
+      else
+	openMess(filename, (int)baseImage, (int)topImage, 1);
+    }else openMess(filename, (int)baseImage, (int)topImage, (int)skipRate);
+  }
 }
 
 /////////////////////////////////////////////////////////
@@ -65,7 +65,10 @@ pix_multiimage :: ~pix_multiimage()
 void pix_multiimage :: openMess(t_symbol *filename, int baseImage, int topImage, int skipRate)
 {
     cleanImages();
-    
+
+    if (m_cache&&m_cache->m_magic!=GEMCACHE_MAGIC)
+      m_cache=NULL;   
+
     if (!topImage)
     {
     	post("GEM: pix_multiimage: requires an int for number of images");
@@ -97,7 +100,7 @@ void pix_multiimage :: openMess(t_symbol *filename, int baseImage, int topImage,
         m_loadedCache->refCount++;
         m_curImage = 0;
         m_numImages = m_loadedCache->numImages;
-        copy2Image(&(m_pixBlock.image), m_loadedCache->images[m_curImage]);
+        m_loadedCache->images[m_curImage]->copy2Image(&m_pixBlock.image);
         m_pixBlock.newimage = 1;
         if (m_cache) m_cache->resendImage = 1;
         return;
@@ -159,7 +162,7 @@ void pix_multiimage :: openMess(t_symbol *filename, int baseImage, int topImage,
     }
 
     m_curImage = 0;
-    copy2Image(&(m_pixBlock.image), newCache->images[m_curImage]);
+    newCache->images[m_curImage]->copy2Image(&m_pixBlock.image);
     m_pixBlock.newimage = 1;
     if (m_cache) m_cache->resendImage = 1;
 
@@ -192,7 +195,7 @@ void pix_multiimage :: render(GemState *state)
     // do we need to reload the image?    
     if (m_cache->resendImage)
     {
-	    refreshImage(&(m_pixBlock.image), m_loadedCache->images[m_curImage]);
+      m_loadedCache->images[m_curImage]->refreshImage(&m_pixBlock.image);
     	m_pixBlock.newimage = 1;
     	m_cache->resendImage = 0;
     }
@@ -218,7 +221,7 @@ void pix_multiimage :: startRendering()
 {
     if (!m_numImages) return;
 
-    refreshImage(&(m_pixBlock.image), m_loadedCache->images[m_curImage]);
+    m_loadedCache->images[m_curImage]->refreshImage(&m_pixBlock.image);
     m_pixBlock.newimage = 1;
 }
 
@@ -228,6 +231,9 @@ void pix_multiimage :: startRendering()
 /////////////////////////////////////////////////////////
 void pix_multiimage :: changeImage(int imgNum)
 {
+  if (m_cache&&m_cache->m_magic!=GEMCACHE_MAGIC)
+    m_cache=NULL;
+
     if (imgNum >= m_numImages)
     {
     	error("GEM: pix_multiimage: selection number too high: %d (max num is %d)", imgNum, m_numImages);
@@ -279,7 +285,7 @@ void pix_multiimage :: cleanImages()
 
 	    m_loadedCache = NULL;
     	m_numImages = 0;
-    	delete [] m_pixBlock.image.data;
+    	m_pixBlock.image.clear();
         m_pixBlock.image.data = NULL;
     }
 }
