@@ -5,6 +5,9 @@ LOG
     Multiply two images together.
 
     Copyright (c) 1997-1998 Mark Danks
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) 2002 James Tittle & Chris Clepper
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -46,17 +49,22 @@ class GEM_EXTERN pix_multiply : public GemPixDualObj
 
     	//////////
     	// Do the processing
-    	virtual void 	processDualImage(imageStruct &image, imageStruct &right);
+    	virtual void 	processRGBA_RGBA(imageStruct &image, imageStruct &right);
 
     	//////////
     	//  This is called whenever a new image comes through.
 		//	The left image is an RGBA, the right is a gray8
-    	virtual void 	processRightGray(imageStruct &image, imageStruct &right); 	
+    	virtual void 	processRGBA_Gray(imageStruct &image, imageStruct &right); 	
 
     	//////////
     	//  This is called whenever a new image comes through.
 		//	Both images are gray8
-    	virtual void 	processBothGray(imageStruct &image, imageStruct &right); 	
+    	virtual void 	processGray_Gray(imageStruct &image, imageStruct &right);
+        
+    	//////////
+    	// Do the processing
+    	virtual void 	processYUV_YUV(imageStruct &image, imageStruct &right);
+        
 };
 
 #endif	// for header file
