@@ -2,11 +2,13 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
+//    Copyright (c) Gnther Geiger.
+//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -17,7 +19,7 @@
 #include "Base/GemMan.h"
 #include "Base/GemCache.h"
 
-CPPEXTERN_NEW(pix_snap)
+CPPEXTERN_NEW_WITH_GIMME(pix_snap)
 
 /////////////////////////////////////////////////////////
 //
@@ -27,12 +29,30 @@ CPPEXTERN_NEW(pix_snap)
 // Constructor
 //
 /////////////////////////////////////////////////////////
-pix_snap :: pix_snap()
-    	  : m_originalImage(NULL),
-    	    m_x(0), m_y(0), m_width(-1), m_height(-1)
+pix_snap :: pix_snap(int argc, t_atom *argv)
+    	  : m_originalImage(NULL)
 {
-    inlet_new(this->x_obj, &this->x_obj->ob_pd, gensym("list"), gensym("vert_pos"));
-    inlet_new(this->x_obj, &this->x_obj->ob_pd, gensym("list"), gensym("vert_size"));
+  m_pixBlock.image = m_imageStruct;
+  m_pixBlock.image.data = NULL;
+  if (argc == 4){
+    m_x = (int)atom_getfloat(&argv[0]);
+    m_y = (int)atom_getfloat(&argv[1]);
+    m_width = (int)atom_getfloat(&argv[2]);
+    m_height = (int)atom_getfloat(&argv[3]);
+  } else if (argc == 2)	{
+    m_x = m_y = 0;
+    m_width = (int)atom_getfloat(&argv[0]);
+    m_height = (int)atom_getfloat(&argv[1]);
+  } else if (argc == 0)	{
+    m_x = m_y = 0;
+    m_width = m_height = 128;
+  } else {
+    error("GEM: pix_snap: needs 0, 2, or 4 values");
+    m_x = m_y = 0;
+    m_width = m_height = 128;
+  }
+  inlet_new(this->x_obj, &this->x_obj->ob_pd, gensym("list"), gensym("vert_pos"));
+  inlet_new(this->x_obj, &this->x_obj->ob_pd, gensym("list"), gensym("vert_size"));
 }
 
 /////////////////////////////////////////////////////////
@@ -50,9 +70,17 @@ pix_snap :: ~pix_snap()
 /////////////////////////////////////////////////////////
 void pix_snap :: snapMess()
 {
+  if (m_cache&&m_cache->m_magic!=GEMCACHE_MAGIC)
+    m_cache=NULL;
+
     if ( !GemMan::windowExists() )
 		return;
         
+	if (m_width <= 0 || m_height <= 0)
+	{
+		error("GEM: pix_snap: Illegal size");
+		return;
+	}
 	// do we need to remake the data?
 	int makeNew = 0;
 
@@ -62,7 +90,7 @@ void pix_snap :: snapMess()
 		if (m_originalImage->xsize != m_width ||
 			m_originalImage->ysize != m_height)
 		{
-			delete [] m_originalImage->data;
+			m_originalImage->clear();
 			delete m_originalImage;
 			m_originalImage = NULL;
 			makeNew = 1;
@@ -77,19 +105,30 @@ void pix_snap :: snapMess()
 		m_originalImage->xsize = m_width;
 		m_originalImage->ysize = m_height;
 		m_originalImage->csize = 4;
+                #ifndef __APPLE__
 		m_originalImage->type  = GL_UNSIGNED_BYTE;
 		m_originalImage->format = GL_RGBA;
-		m_originalImage->data = new
-    		unsigned char[m_originalImage->xsize * m_originalImage->ysize * m_originalImage->csize];
+                #else
+                m_originalImage->type  = GL_UNSIGNED_INT_8_8_8_8_REV;
+		m_originalImage->format = GL_BGRA_EXT;
+                #endif
+		m_originalImage->allocate(m_originalImage->xsize * m_originalImage->ysize * m_originalImage->csize);
 	}
+#ifdef __APPLE__
+    glFinish();
+    glPixelStorei(GL_PACK_ALIGNMENT, 4);
+    glPixelStorei(GL_PACK_ROW_LENGTH, 0);
+    glPixelStorei(GL_PACK_SKIP_ROWS, 0);
+    glPixelStorei(GL_PACK_SKIP_PIXELS, 0);
+#endif
 
     glReadPixels(m_x, m_y, m_width, m_height,
     	    	 m_originalImage->format, m_originalImage->type, m_originalImage->data);    
            
-	if (m_cache)
+    if (m_cache)
 		m_cache->resendImage = 1;
 
-    post("snapped image"); 
+    //post("GEM: pix_snap: snapped image"); 
 }
 
 /////////////////////////////////////////////////////////
@@ -103,9 +142,9 @@ void pix_snap :: render(GemState *state)
 		return;
     
     // do we need to reload the image?    
-    if (m_cache->resendImage)
+    if (m_cache&&m_cache->resendImage)
     {
-		refreshImage(&(m_pixBlock.image), m_originalImage);
+      m_originalImage->refreshImage(&m_pixBlock.image);
     	m_pixBlock.newimage = 1;
     	m_cache->resendImage = 0;
     }
@@ -152,12 +191,10 @@ void pix_snap :: cleanImage()
     // release previous data
     if (m_originalImage)
     {
-		delete [] m_originalImage->data;
-		delete m_originalImage;
-		m_originalImage = NULL;
+      delete m_originalImage;
+      m_originalImage = NULL;
 
-    	delete [] m_pixBlock.image.data;
-        m_pixBlock.image.data = NULL;
+      m_pixBlock.image.clear();
     }
 }
 
